/*----------------------------------------------------------------

Class: adobe

Properties:
console - undefined
debugging - boolean
options - hash
version - string
COLOR_DEPTH - number or NaN
DIR - string
FILE - string
PATH - string
SCRIPT_BUILD - number or NaN
SCRIPT_ENGINE - string
SCRIPT_VERSION - number or NaN

Author: 
btapley

----------------------------------------------------------------*/

var adobe = Class.create({
	initialize: function(options) {
		var src = document.getElementById("adobe").getAttribute("src"),
		lastfolder = src.lastIndexOf("/"),
		folders = src.substring(0, lastfolder),
		file = src.substring(lastfolder+1),
		q = src.split("?")[1],
		options = options || {},
		NAN = parseInt("");

		if(q) { Object.extend(options, q.toQueryParams()); }

		this.version = "0.1";
		this.options = options;
		this.debugging = false;
		this.console;
		this.DIR = folders;
		this.PATH = folders+"/";
		this.FILE = file;
		this.COLOR_DEPTH = screen.colorDepth || NAN;
		this.SCRIPT_ENGINE = (function() {
			try {
				return ScriptEngine();
			} catch(e) {
				return "JavaScript";	
			}     
		})();
		this.SCRIPT_VERSION = (this.SCRIPT_ENGINE == "JScript") ? (ScriptEngineMajorVersion()+ScriptEngineMinorVersion()/10) : NAN;
		this.SCRIPT_BUILD = (this.SCRIPT_ENGINE == "JScript") ? ScriptEngineBuildVersion() : NAN;
	},
/*----------------------------------------------------------------	

	Method: debug
	Set to true, this provides <Console> methods in the adobe object eg. adobe.log

>	adobe.debug(true)

	Parameters:
	bool - boolean
	
	Returned Value:
	Nothing

----------------------------------------------------------------*/
	debug: function(bool) {
		if(this.debugging === bool) {return;}
		this.debugging = !!bool;
		JSAN.errorLevel = (this.debugging) ? "die" : "none";
		JSAN.use("adobe.Console");
		var console = new adobe.Console();		
		Object.extend(this, console);
	}
});

adobe = new adobe();

/*----------------------------------------------------------------	

	JSAN implementation

----------------------------------------------------------------*/

var JSAN=function(){JSAN.addRepository(arguments)};JSAN.VERSION=0.1;JSAN.globalScope=self;JSAN.includePath=[".","lib"];JSAN.errorLevel="none";JSAN.errorMessage="";JSAN.loaded={};JSAN.use=function(){var B=JSAN.require(arguments[0]);if(!B){return null}var A=JSAN._parseUseArgs.apply(JSAN,arguments).importList;JSAN.exporter(B,A);return B};JSAN.require=function(pkg){var path=JSAN._convertPackageToPath(pkg);if(JSAN.loaded[path]){return JSAN.loaded[path]}try{var classdef=eval(pkg);if(typeof classdef!="undefined"){return classdef}}catch(e){}for(var i=0;i<JSAN.includePath.length;i++){var js;try{var url=JSAN._convertPathToUrl(path,JSAN.includePath[i]);js=JSAN._loadJSFromUrl(url)}catch(e){if(i==JSAN.includePath.length-1){throw e}}if(js!=null){var classdef=JSAN._createScript(js,pkg);JSAN.loaded[path]=classdef;return classdef}}return false};JSAN.exporter=function(){JSAN._exportItems.apply(JSAN,arguments)};JSAN.addRepository=function(){var A=JSAN._flatten(arguments);for(var B=A.length-1;B>=0;B--){JSAN.includePath.unshift(A[B])}return JSAN};JSAN._flatten=function(A){var C=new Array();for(var B=0;B<A.length;B++){if(typeof A[B]=="object"){C=JSAN._flatten(A[B],C)}else{C.push(A[B])}}return C};JSAN._findMyPath=function(){if(document){var A=document.getElementsByTagName("script");for(var D=0;D<A.length;D++){var F=A[D].getAttribute("src");if(F){var E=F.match(/^(.*?)\/?JSAN.js/);if(E&&E[1]){var C=E[1];for(var B=0;B<JSAN.includePath.length;B++){if(JSAN.includePath[B]==C){return }}JSAN.addRepository(C)}}}}};JSAN._findMyPath();JSAN._convertPathToUrl=function(B,A){return A.concat("/"+B)};JSAN._convertPackageToPath=function(A){var B=A.replace(/\./g,"/");B=B.concat(".js");return B};JSAN._parseUseArgs=function(){var B=arguments[0];var A=[];for(var C=1;C<arguments.length;C++){A.push(arguments[C])}return{pkg:B,importList:A}};JSAN._loadJSFromUrl=function(A){return new JSAN.Request().getText(A)};JSAN._findExportInList=function(C,B){if(C==null){return false}for(var A=0;A<C.length;A++){if(C[A]==B){return true}}return false};JSAN._findExportInTag=function(A,C){if(A==null){return[]}for(var B in A){if(B==C){return A[B]}}return[]};JSAN._exportItems=function(I,A){var E=new Array();var D=I.EXPORT;var F=I.EXPORT_OK;var G=I.EXPORT_TAGS;if(A.length>0){A=JSAN._flatten(A);for(var C=0;C<A.length;C++){var B=A[C];if(JSAN._findExportInList(D,B)||JSAN._findExportInList(F,B)){E.push(B);continue}var H=JSAN._findExportInTag(G,B);for(var C=0;C<H.length;C++){E.push(H[C])}}}else{E=D}JSAN._exportList(I,E)};JSAN._exportList=function(D,B){if(typeof (B)!="object"){return null}for(var C=0;C<B.length;C++){var A=B[C];if(JSAN.globalScope[A]==null){JSAN.globalScope[A]=D[A]}}};JSAN._makeNamespace=function(js,pkg){var spaces=pkg.split(".");var parent=JSAN.globalScope;eval(js);var classdef=eval(pkg);for(var i=0;i<spaces.length;i++){var name=spaces[i];if(i==spaces.length-1){if(typeof parent[name]=="undefined"){parent[name]=classdef;if(typeof classdef.prototype!="undefined"){parent[name].prototype=classdef.prototype}}}else{if(parent[name]==undefined){parent[name]={}}}parent=parent[name]}return classdef};JSAN._handleError=function(A,B){if(!B){B=JSAN.errorLevel}JSAN.errorMessage=A;switch(B){case"none":break;case"warn":alert(A);break;case"die":default:throw new Error(A);break}};JSAN._createScript=function(C,A){try{return JSAN._makeNamespace(C,A)}catch(B){JSAN._handleError("Could not create namespace["+A+"]: "+B)}return null};JSAN.prototype={use:function(){JSAN.use.apply(JSAN,arguments)}};JSAN.Request=function(A){if(JSAN.globalScope.XMLHttpRequest){this._req=new XMLHttpRequest()}else{this._req=new ActiveXObject("Microsoft.XMLHTTP")}};JSAN.Request.prototype={_req:null,getText:function(A){this._req.open("GET",A,false);try{this._req.send(null);if(this._req.status==200||this._req.status==0){return this._req.responseText}}catch(B){JSAN._handleError("File not found: "+A);return null}JSAN._handleError("File not found: "+A);return null}};

Object.extend(adobe, {
/*----------------------------------------------------------------	

	Method: use

>	adobe.use("adobe.foo")

	Parameters:
	namespace - string
	
	Returned Value:
	Class reference
	
	Delegate for:
	<http://www.openjsan.org/src/c/cw/cwest/JSAN-0.08/doc/html/JSAN.html>

----------------------------------------------------------------*/
	use: JSAN.use,
/*----------------------------------------------------------------	

	Method: addRepository
	
>	adobe.addRepository("/path/to/repository");
	
	Parameters:
	path - string
	
	Returned Value:
	JSAN Object reference
	
	Delegate for:
	<http://www.openjsan.org/src/c/cw/cwest/JSAN-0.08/doc/html/JSAN.html>

----------------------------------------------------------------*/
	addRepository: JSAN.addRepository,
/*----------------------------------------------------------------	

	Method: setLoaded

>	adobe.setLoaded(adobe.foo, adobe.PATH+"adobe/foo.js")

	Parameters:
	module - object reference
	file - string
	
	Returned Value:
	None
	
	Delegate for:
	<http://www.openjsan.org/src/c/cw/cwest/JSAN-0.08/doc/html/JSAN.html>

----------------------------------------------------------------*/
	setLoaded: function(module, file) {
		JSAN.loaded[file] = module;
	}
});

adobe.addRepository(adobe.DIR);
adobe.setLoaded(adobe, adobe.FILE);

/*----------------------------------------------------------------	

	Asset Linking

----------------------------------------------------------------*/

adobe.use("adobe.Loader");

Object.extend(adobe, {
/*----------------------------------------------------------------	

	Method: link
	
>	adobe.link("path/to/file.css", {media:"screen"})
	
	Parameters:
	path - relative path from adobe.js file as string
	params - hash
	
	Returned Value:
	0 = Nothing, 1 = Done, 2 = Error

----------------------------------------------------------------*/
	link: adobe.Loader.requireAsset.wrap(function($proceed, path, params) {
		$proceed(adobe.PATH + path, params);	
	}),
/*----------------------------------------------------------------	

	Method: setLinked

>	adobe.setLinked("/path/to/file.css")

	Parameters:
	path - relative path from adobe.js file as string
	
	Returned Value:
	None

----------------------------------------------------------------*/
	setLinked: adobe.Loader.setLoaded.wrap(function($proceed, path) {
		$proceed(adobe.PATH + path);
	})
});

adobe.setLinked("lib/prototype.js");
adobe.setLinked("lib/JSAN.js");